Attached

Struct Attached 

pub struct Attached { /* private fields */ }
A container that attaches elements to the top, bottom, left, or right of an inner element.

Uses absolute positioning and measures the attached element’s size to offset it correctly relative to the inner content.

Example

fn app() -> impl IntoElement {
    let mut open = use_state(|| false);

    Attached::new(
        Button::new()
            .on_press(move |_| open.toggle())
            .child("Toggle"),
    )
    .bottom()
    .maybe_child(open().then(|| label().text("Attached below!")))
}

Implementations

Source

impl Attached

pub fn new(inner: impl IntoElement) -> Self

pub fn position(self, position: AttachedPosition) -> Self

pub fn top(self) -> Self

pub fn bottom(self) -> Self

pub fn left(self) -> Self

pub fn right(self) -> Self